==> haskell-cmark-gfm-0.1.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark-gfm
version: 0.1.3
id: cmark-gfm-0.1.3-28OjSF4mAR16RhLrmDcrH7
key: cmark-gfm-0.1.3-28OjSF4mAR16RhLrmDcrH7
license: BSD-3-Clause
copyright: (C) 2015--17 John MacFarlane, (C) 2017 Yuki Izumi
maintainer: kivikakk@github.com
author: Yuki Izumi
homepage: https://github.com/kivikakk/cmark-gfm-hs
synopsis: Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.28.0) and does not require prior installation of the
    C library.
category: Text
abi: 0e690b1d304c9b4105053990835ac3da
exposed: True
exposed-modules:
    CMarkGFM
import-dirs: /usr/lib/ghc-8.4.3/site-local/cmark-gfm-0.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/cmark-gfm-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cmark-gfm-0.1.3
hs-libraries: HScmark-gfm-0.1.3-28OjSF4mAR16RhLrmDcrH7
includes:
    cmark.h
depends:
    base-4.11.1.0 text-1.2.3.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html: /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.1.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark-gfm
version: 0.1.5
id: cmark-gfm-0.1.5-AvnXgi7Mts9sGqig73mCZ
key: cmark-gfm-0.1.5-AvnXgi7Mts9sGqig73mCZ
license: BSD-3-Clause
copyright: (C) 2015--17 John MacFarlane, (C) 2017 Ashe Connor
maintainer: kivikakk@github.com
author: Ashe Connor
homepage: https://github.com/kivikakk/cmark-gfm-hs
synopsis: Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.28.0) and does not require prior installation of the
    C library.
category: Text
abi: 34716da549873f4c3e09aade28adf1b0
exposed: True
exposed-modules:
    CMarkGFM
import-dirs: /usr/lib/ghc-8.4.3/site-local/cmark-gfm-0.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/cmark-gfm-0.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cmark-gfm-0.1.5
hs-libraries: HScmark-gfm-0.1.5-AvnXgi7Mts9sGqig73mCZ
extra-libraries:
    cmark-gfm cmark-gfm-extensions
depends:
    base-4.11.1.0 text-1.2.3.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html: /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
